## 1.16.11 (2022-03-01)

Add six.create_bound_method dunders to allowlist (#7409)

Closes: #7404

## 1.16.10 (2022-01-19)

Use PEP 585 syntax in Python 2, `protobuf` & `_ast` stubs, where possible (#6949)

## 1.16.9 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 1.16.7 (2022-01-03)

Add six.moves.copyreg six stubs (#6793)

## 1.16.6 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 1.16.5 (2021-12-27)

Enable stubtest for six (#6699)

## 1.16.4 (2021-12-25)

Add a 'stubtest' flag to METADATA.toml (#6687)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 1.16.3 (2021-11-28)

dummy_thread/ing: remove in 3.9 (#6408)

https://bugs.python.org/issue37312

## 1.16.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

